%global modname velruse

Name:           python-%{modname}
Version:        1.1.1
Release:        12%{?dist}
Summary:        Simplify third-party authentication for web applications

License:        MIT
URL:            http://pypi.python.org/pypi/%{modname}
Source0:        http://pypi.python.org/packages/source/v/%{modname}/%{modname}-%{version}.tar.gz
# https://github.com/bbangert/velruse/pull/134
Patch0:         python-velruse-extract-extra-data.patch

BuildArch:      noarch

BuildRequires:  python2-devel
BuildRequires:  python2-setuptools

BuildRequires:  python2-openid
BuildRequires:  python2-oauth2
BuildRequires:  python2-pyramid
BuildRequires:  python2-requests
BuildRequires:  python2-anykeystore

# No test dependencies are installed since they require python-selenium
# We don't run the tests.


%global _description\
Velruse is a set of authentication routines that provide a unified way\
to have a website user authenticate to a variety of different identity\
providers and/or a variety of different authentication schemes.\
\
It is similar in some ways to Janrain Engage with the exception of being\
open-source, locally installable, and easily pluggable for custom identity\
providers and authentication schemes.\
\
You can run Velruse as a stand-alone service for use with your websites\
regardless of the language they’re written in. While Velruse itself is\
written in Python, since it can interact with your website purely via HTTP\
POST’s.\
\
Velruse can:\
\
 - Normalize identity information from varying provider sources (OpenID,\
   Google, Facebook, etc.) to Portable Contacts.\
 - Simplify complex authentication protocols by providing a simple\
   consistent API\
 - Provide extension points for other authentication systems, write your\
   own auth provider to handle CAS, LDAP, and use it with ease\
 - Integrate with most web applications regardless of the language used to\
   write the website\
\
Velruse aims to simplify authenticating a user. It provides auth provider‘s\
that handle authenticating to a variety of identity providers with multiple\
authentication schemes (LDAP, SAML, etc.). Eventually, Velruse will include\
widgets similar to RPXNow that allow one to customize a login/registration\
widget so that a website user can select a preferred identity provider to\
use to sign-in. In the mean-time, effort is focused on increasing the\
available auth provider‘s for the commonly used authentication schemes and\
identity providers (Facebook, Google, OpenID, etc). Unlike other\
authentication libraries for use with web applications, a website using\
Velruse for authentication does not have to be written in any particular\
language.

%description %_description

%package -n python2-%{modname}
Summary: %summary
Requires:       python2-openid
Requires:       python2-oauth2
Requires:       python2-pyramid
Requires:       python2-requests
Requires:       python2-anykeystore
Requires:       python2-requests-oauthlib
%{?python_provide:%python_provide python2-%{modname}}

%description -n python2-%{modname} %_description

%prep
%setup -q -n %{modname}-%{version}
%patch0 -p1

# Remove bundle egg info in case it exists
rm -rf %{modname}.egg-info

%build
%{__python2} setup.py build

%install
%{__python2} setup.py install -O1 --skip-build --root=%{buildroot}

%check
# No tests are run since they require python-selenium

%files -n python2-%{modname}
%doc PKG-INFO
%{python2_sitelib}/%{modname}/
%{python2_sitelib}/%{modname}-%{version}*

%changelog
* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Jul 24 2018 Kevin Fenzi <kevin@scrye.com> - 1.1.1-11
- Fix FTBFS bug #1605978

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jan 31 2018 Iryna Shcherbina <ishcherb@redhat.com> - 1.1.1-8
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Sat Aug 19 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.1.1-7
- Python 2 binary package renamed to python2-velruse
  See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jan 23 2015 Ralph Bean <rbean@redhat.com> - 1.1.1-1
- Latest upstream.

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Oct 17 2013 Ralph Bean <rbean@redhat.com> - 1.0.3-6
- Apply patch introducing an new extension point

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Nov 28 2012 Ralph Bean <rbean@redhat.com> - 1.0.3-3
- Added forgotten dependencies.
* Sun Nov 11 2012 Ralph Bean <rbean@redhat.com> - 1.0.3-2
- Remove bundled egg-info in %%prep.
* Thu Nov 08 2012 Ralph Bean <rbean@redhat.com> - 1.0.3-1
- Initial packaging for fedora.
